@@ -25,16 +25,6 @@
 
 class CControllerActionLogList extends CController {
 
-	/**
-	 * @var string  Time from.
-	 */
-	private $from;
-
-	/**
-	 * @var string  Time till.
-	 */
-	private $to;
-
 	protected function init(): void {
 		$this->disableCsrfValidation();
 	}
@@ -53,24 +43,11 @@ class CControllerActionLogList extends CController {
 			'to' =>						'range_time'
 		];
 
-		$ret = $this->validateInput($fields);
+		$ret = $this->validateInput($fields) && $this->validateTimeSelectorPeriod();
 
 		if (!$ret) {
 			$this->setResponse(new CControllerResponseFatal());
 		}
-		else {
-			if ($this->hasInput('from') || $this->hasInput('to')) {
-				validateTimeSelectorPeriod(
-					$this->hasInput('from') ? $this->getInput('from') : null,
-					$this->hasInput('to') ? $this->getInput('to') : null
-				);
-			}
-
-			$this->from = $this->getInput('from', CProfile::get('web.actionlog.filter.from',
-				'now-'.CSettingsHelper::get(CSettingsHelper::PERIOD_DEFAULT)
-			));
-			$this->to = $this->getInput('to', CProfile::get('web.actionlog.filter.to', 'now'));
-		}
 
 		return $ret;
 	}
@@ -87,6 +64,16 @@ class CControllerActionLogList extends CController {
 			$this->deleteProfiles();
 		}
 
+		$timeselector_options = [
+			'profileIdx' => 'web.actionlog.filter',
+			'profileIdx2' => 0,
+			'from' => null,
+			'to' => null
+		];
+
+		$this->getInputs($timeselector_options, ['from', 'to']);
+		updateTimeSelectorPeriod($timeselector_options);
+
 		$data = [
 			'page' => $this->getInput('page', 1),
 			'userids' => CProfile::getArray('web.actionlog.filter.userids', []),
@@ -100,12 +87,7 @@ class CControllerActionLogList extends CController {
 			'messages' => CProfile::get('web.actionlog.filter.messages', ''),
 			'alerts' => [],
 			'action' => $this->getAction(),
-			'timeline' => getTimeSelectorPeriod([
-				'profileIdx' => 'web.actionlog.filter',
-				'profileIdx2' => 0,
-				'from' => $this->from,
-				'to' => $this->to
-			]),
+			'timeline' => getTimeSelectorPeriod($timeselector_options),
 			'active_tab' => CProfile::get('web.actionlog.filter.active', 1)
 		];
 
@@ -233,8 +215,6 @@ class CControllerActionLogList extends CController {
 			PROFILE_TYPE_ID);
 		CProfile::updateArray('web.actionlog.filter.statuses', $this->getInput('filter_statuses', []), PROFILE_TYPE_ID);
 		CProfile::update('web.actionlog.filter.messages', $this->getInput('filter_messages', ''), PROFILE_TYPE_STR);
-		CProfile::update('web.actionlog.filter.from', $this->from, PROFILE_TYPE_STR);
-		CProfile::update('web.actionlog.filter.to', $this->to, PROFILE_TYPE_STR);
 	}
 
 	private function deleteProfiles(): void {
