@@ -338,7 +338,7 @@ class CControllerAuthenticationUpdate extends CController {
 			];
 
 			if ($this->getInput('ldap_jit_status', JIT_PROVISIONING_DISABLED) == JIT_PROVISIONING_ENABLED) {
-				$fields['jit_provision_interval'] = '1h';
+				$fields['jit_provision_interval'] = DB::getDefault('config', 'jit_provision_interval');
 			}
 		}
 
@@ -417,7 +417,7 @@ class CControllerAuthenticationUpdate extends CController {
 
 			if (array_key_exists('userdirectoryid', $ldap_server)) {
 				$userdirectoryid_map[$row_index] = $ldap_server['userdirectoryid'];
-				$upd_ldap_servers[] = $ldap_server;
+				$upd_ldap_servers[] = $ldap_server + ['provision_media' => []];
 			}
 			else {
 				$userdirectoryid_map[$row_index] = null;
