@@ -24,16 +24,6 @@
  */
 class CControllerChartsView extends CControllerCharts {
 
-	/**
-	 * @var string  Time from.
-	 */
-	private $from;
-
-	/**
-	 * @var string  Time till.
-	 */
-	private $to;
-
 	protected function init() {
 		$this->disableCsrfValidation();
 	}
@@ -59,19 +49,6 @@ class CControllerChartsView extends CControllerCharts {
 		if (!$ret) {
 			$this->setResponse(new CControllerResponseFatal());
 		}
-		else {
-			if ($this->hasInput('from') || $this->hasInput('to')) {
-				validateTimeSelectorPeriod(
-					$this->hasInput('from') ? $this->getInput('from') : null,
-					$this->hasInput('to') ? $this->getInput('to') : null
-				);
-			}
-
-			$this->from = $this->getInput('from', CProfile::get('web.charts.filter.from',
-				'now-'.CSettingsHelper::get(CSettingsHelper::PERIOD_DEFAULT)
-			));
-			$this->to = $this->getInput('to', CProfile::get('web.charts.filter.to', 'now'));
-		}
 
 		return $ret;
 	}
@@ -98,8 +75,6 @@ class CControllerChartsView extends CControllerCharts {
 			CProfile::update('web.charts.filter.show',
 				$this->getInput('filter_show', GRAPH_FILTER_ALL), PROFILE_TYPE_INT
 			);
-			CProfile::update('web.charts.filter.from', $this->from, PROFILE_TYPE_STR);
-			CProfile::update('web.charts.filter.to', $this->to, PROFILE_TYPE_STR);
 		}
 
 		$filter_hostids = CProfile::getArray('web.charts.filter.hostids', []);
@@ -109,15 +84,18 @@ class CControllerChartsView extends CControllerCharts {
 		$subfilter_tagnames = CProfile::getArray('web.charts.subfilter.tagnames', []);
 		$subfilter_tags = json_decode(CProfile::get('web.charts.subfilter.tags', '{}'), true);
 
+		$timeselector_options = [
+			'profileIdx' => 'web.charts.filter',
+			'profileIdx2' => 0,
+			'from' => $this->hasInput('from') ? $this->getInput('from') : null,
+			'to' => $this->hasInput('to') ? $this->getInput('to') : null
+		];
+		updateTimeSelectorPeriod($timeselector_options);
+
 		$data = [
 			'view_as' => $this->getInput('view_as', HISTORY_GRAPH),
 			'ms_hosts' => [],
-			'timeline' => getTimeSelectorPeriod([
-				'profileIdx' => 'web.charts.filter',
-				'profileIdx2' => 0,
-				'from' => $this->from,
-				'to' => $this->to
-			]),
+			'timeline' => getTimeSelectorPeriod($timeselector_options),
 			'active_tab' => CProfile::get('web.charts.filter.active', 1),
 			'filter_hostids' => $filter_hostids,
 			'filter_name' => $filter_name,
