@@ -1,8 +1,7 @@
-<?php declare(strict_types = 1);
-
+<?php declare(strict_types = 0);
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -25,6 +24,74 @@
  */
 abstract class CControllerHost extends CController {
 
+	// Filter idx prefix.
+	const FILTER_IDX = 'web.monitoring.hosts';
+
+	// Filter fields default values.
+	const FILTER_FIELDS_DEFAULT = [
+		'name' => '',
+		'groupids' => [],
+		'ip' => '',
+		'dns' => '',
+		'port' => '',
+		'status' => -1,
+		'evaltype' => TAG_EVAL_TYPE_AND_OR,
+		'tags' => [],
+		'severities' => [],
+		'show_suppressed' => ZBX_PROBLEM_SUPPRESSED_FALSE,
+		'maintenance_status' => HOST_MAINTENANCE_STATUS_ON,
+		'page' => null,
+		'sort' => 'name',
+		'sortorder' => ZBX_SORT_UP
+	];
+
+	/**
+	 * Get host list results count for passed filter.
+	 *
+	 * @param array  $filter                        Filter options.
+	 * @param string $filter['name']                Filter hosts by name.
+	 * @param array  $filter['groupids']            Filter hosts by host groups.
+	 * @param string $filter['ip']                  Filter hosts by IP.
+	 * @param string $filter['dns']	                Filter hosts by DNS.
+	 * @param string $filter['port']                Filter hosts by port.
+	 * @param string $filter['status']              Filter hosts by status.
+	 * @param string $filter['evaltype']            Filter hosts by tags.
+	 * @param string $filter['tags']                Filter hosts by tag names and values.
+	 * @param string $filter['severities']          Filter problems on hosts by severities.
+	 * @param string $filter['show_suppressed']     Filter suppressed problems.
+	 * @param int    $filter['maintenance_status']  Filter hosts by maintenance.
+	 *
+	 * @return int
+	 */
+	protected function getCount(array $filter): int {
+		$groupids = $filter['groupids'] ? getSubGroups($filter['groupids']) : null;
+
+		return (int) API::Host()->get([
+			'countOutput' => true,
+			'evaltype' => $filter['evaltype'],
+			'tags' => $filter['tags'],
+			'inheritedTags' => true,
+			'groupids' => $groupids,
+			'severities' => $filter['severities'] ? $filter['severities'] : null,
+			'withProblemsSuppressed' => $filter['severities']
+				? (($filter['show_suppressed'] == ZBX_PROBLEM_SUPPRESSED_TRUE) ? null : false)
+				: null,
+			'search' => [
+				'name' => ($filter['name'] === '') ? null : $filter['name'],
+				'ip' => ($filter['ip'] === '') ? null : $filter['ip'],
+				'dns' => ($filter['dns'] === '') ? null : $filter['dns']
+			],
+			'filter' => [
+				'status' => ($filter['status'] == -1) ? null : $filter['status'],
+				'port' => ($filter['port'] === '') ? null : $filter['port'],
+				'maintenance_status' => ($filter['maintenance_status'] == HOST_MAINTENANCE_STATUS_ON)
+					? null
+					: HOST_MAINTENANCE_STATUS_OFF
+			],
+			'limit' => CSettingsHelper::get(CSettingsHelper::SEARCH_LIMIT) + 1
+		]);
+	}
+
 	/**
 	 * Prepares the host list based on the given filter and sorting options.
 	 *
@@ -41,54 +108,14 @@ abstract class CControllerHost extends CController {
 	 * @param string $filter['show_suppressed']     Filter suppressed problems.
 	 * @param int    $filter['maintenance_status']  Filter hosts by maintenance.
 	 * @param int    $filter['page']                Page number.
-	 * @param string $sort						    Sorting field.
-	 * @param string $sortorder                     Sorting order.
+	 * @param string $filter['sort']                Sorting field.
+	 * @param string $filter['sortorder']           Sorting order.
 	 *
 	 * @return array
 	 */
-	protected function prepareData(array $filter, string $sort, string $sortorder): array {
-		$child_groups = [];
-
-		// Multiselect host groups.
-		$multiselect_hostgroup_data = [];
-		if ($filter['groupids']) {
-			$filter_groups = API::HostGroup()->get([
-				'output' => ['groupid', 'name'],
-				'groupids' => $filter['groupids'],
-				'preservekeys' => true
-			]);
-
-			if ($filter_groups) {
-				foreach ($filter_groups as $group) {
-					$multiselect_hostgroup_data[] = [
-						'id' => $group['groupid'],
-						'name' => $group['name']
-					];
-
-					$child_groups[] = $group['name'].'/';
-				}
-			}
-			else {
-				$filter['groupids'] = [];
-			}
-		}
-
-		$groupids = null;
-
-		if ($child_groups) {
-			$filter_groups += API::HostGroup()->get([
-				'output' => ['groupid'],
-				'search' => ['name' => $child_groups],
-				'startSearch' => true,
-				'searchByAny' => true,
-				'preservekeys' => true
-			]);
-
-			$groupids = array_keys($filter_groups);
-		}
-
-		$config = select_config();
-
+	protected function getData(array $filter): array {
+		$limit = CSettingsHelper::get(CSettingsHelper::SEARCH_LIMIT) + 1;
+		$groupids = $filter['groupids'] ? getSubGroups($filter['groupids']) : null;
 		$hosts = API::Host()->get([
 			'output' => ['hostid', 'name', 'status'],
 			'evaltype' => $filter['evaltype'],
@@ -109,30 +136,30 @@ abstract class CControllerHost extends CController {
 				'port' => ($filter['port'] === '') ? null : $filter['port'],
 				'maintenance_status' => ($filter['maintenance_status'] == HOST_MAINTENANCE_STATUS_ON)
 					? null
-					: HOST_MAINTENANCE_STATUS_OFF,
+					: HOST_MAINTENANCE_STATUS_OFF
 			],
 			'sortfield' => 'name',
-			'limit' => $config['search_limit'] + 1,
+			'limit' => $limit,
 			'preservekeys' => true
 		]);
 
 		// Sort for paging so we know which IDs go to which page.
-		CArrayHelper::sort($hosts, [['field' => $sort, 'order' => $sortorder]]);
+		CArrayHelper::sort($hosts, [['field' => $filter['sort'], 'order' => $filter['sortorder']]]);
 
-		$view_curl = (new CUrl('zabbix.php'))->setArgument('action', 'host.view');
+		$view_curl = (new CUrl())->setArgument('action', 'host.view');
+		$paging_arguments = array_filter(array_intersect_key($filter, self::FILTER_FIELDS_DEFAULT));
+		array_map([$view_curl, 'setArgument'], array_keys($paging_arguments), $paging_arguments);
 
 		// Split result array and create paging.
-		$paging = CPagerHelper::paginate($filter['page'], $hosts, $sortorder, $view_curl);
+		$paging = CPagerHelper::paginate($filter['page'], $hosts, $filter['sortorder'], $view_curl);
 
 		// Get additional data to limited host amount.
 		$hosts = API::Host()->get([
 			'output' => ['hostid', 'name', 'status', 'maintenance_status', 'maintenanceid', 'maintenance_type',
-				'available', 'snmp_available', 'jmx_available', 'ipmi_available', 'error', 'ipmi_error', 'snmp_error',
-				'jmx_error'
+				'active_available'
 			],
-			'selectInterfaces' => ['ip', 'dns', 'port', 'main', 'type', 'useip'],
+			'selectInterfaces' => ['ip', 'dns', 'port', 'main', 'type', 'useip', 'available', 'error', 'details'],
 			'selectGraphs' => API_OUTPUT_COUNT,
-			'selectScreens' => API_OUTPUT_COUNT,
 			'selectHttpTests' => API_OUTPUT_COUNT,
 			'selectTags' => ['tag', 'value'],
 			'selectInheritedTags' => ['tag', 'value'],
@@ -140,7 +167,13 @@ abstract class CControllerHost extends CController {
 			'preservekeys' => true
 		]);
 		// Re-sort the results again.
-		CArrayHelper::sort($hosts, [['field' => $sort, 'order' => $sortorder]]);
+		CArrayHelper::sort($hosts, [['field' => $filter['sort'], 'order' => $filter['sortorder']]]);
+
+		$hostids = array_column($hosts, 'hostid');
+
+		// Get count for every host with item type ITEM_TYPE_ZABBIX_ACTIVE (7) and ITEM_TYPE_ZABBIX (0).
+		$active_item_count_by_hostid = getItemTypeCountByHostId(ITEM_TYPE_ZABBIX_ACTIVE, $hostids);
+		$passive_item_count_by_hostid = getItemTypeCountByHostId(ITEM_TYPE_ZABBIX, $hostids);
 
 		$maintenanceids = [];
 
@@ -159,9 +192,19 @@ abstract class CControllerHost extends CController {
 			'objectids' => array_keys($triggers),
 			'source' => EVENT_SOURCE_TRIGGERS,
 			'object' => EVENT_OBJECT_TRIGGER,
-			'suppressed' => ($filter['show_suppressed'] == ZBX_PROBLEM_SUPPRESSED_TRUE) ? null : false
+			'suppressed' => ($filter['show_suppressed'] == ZBX_PROBLEM_SUPPRESSED_TRUE) ? null : false,
+			'symptom' => false
 		]);
 
+		$items = API::Item()->get([
+			'countOutput' => true,
+			'groupCount' => true,
+			'hostids' => array_keys($hosts),
+			'webitems' =>true,
+			'monitored' => true
+		]);
+		$items_count = array_combine(array_column($items, 'hostid'), array_column($items, 'rowscount'));
+
 		// Group all problems per host per severity.
 		$host_problems = [];
 		foreach ($problems as $problem) {
@@ -171,6 +214,25 @@ abstract class CControllerHost extends CController {
 		}
 
 		foreach ($hosts as &$host) {
+			// Add active checks interface if host have items with type ITEM_TYPE_ZABBIX_ACTIVE (7).
+			if (array_key_exists($host['hostid'], $active_item_count_by_hostid)
+					&& $active_item_count_by_hostid[$host['hostid']] > 0) {
+				$host['interfaces'][] = [
+					'type' => INTERFACE_TYPE_AGENT_ACTIVE,
+					'available' => $host['active_available'],
+					'error' => ''
+				];
+			}
+			unset($host['active_available']);
+
+			$host['has_passive_checks'] = array_key_exists($host['hostid'], $passive_item_count_by_hostid)
+				&& $passive_item_count_by_hostid[$host['hostid']] > 0;
+
+			$host['items_count'] = array_key_exists($host['hostid'], $items_count) ? $items_count[$host['hostid']] : 0;
+
+			// Count number of dashboards for each host.
+			$host['dashboards'] = count(getHostDashboards($host['hostid']));
+
 			CArrayHelper::sort($host['interfaces'], [['field' => 'main', 'order' => ZBX_SORT_DOWN]]);
 
 			if ($host['status'] == HOST_STATUS_MONITORED && $host['maintenance_status'] == HOST_MAINTENANCE_STATUS_ON) {
@@ -234,12 +296,74 @@ abstract class CControllerHost extends CController {
 
 		return [
 			'paging' => $paging,
-			'view_curl' => $view_curl,
 			'hosts' => $hosts,
-			'maintenances' => $maintenances,
-			'multiselect_hostgroup_data' => $multiselect_hostgroup_data,
-			'filter' => $filter,
-			'config' => $config
+			'maintenances' => $maintenances
 		];
 	}
+
+	/**
+	 * Get additional data for filters. Selected groups for multiselect, etc.
+	 *
+	 * @param array $filter  Filter fields values array.
+	 *
+	 * @return array
+	 */
+	protected function getAdditionalData($filter): array {
+		$data = [];
+
+		if ($filter['groupids']) {
+			$groups = API::HostGroup()->get([
+				'output' => ['groupid', 'name'],
+				'groupids' => $filter['groupids']
+			]);
+			$data['groups_multiselect'] = CArrayHelper::renameObjectsKeys(array_values($groups), ['groupid' => 'id']);
+		}
+
+		return $data;
+	}
+
+	/**
+	 * Clean the filter from non-existing host group IDs.
+	 *
+	 * @param array $filter
+	 *
+	 * $filter = [
+	 *     'groupids' => (array)  Group IDs from filter to check.
+	 * ]
+	 *
+	 * @return array
+	 */
+	protected static function sanitizeFilter(array $filter): array {
+		if ($filter['groupids']) {
+			$groups = API::HostGroup()->get([
+				'output' => [],
+				'groupids' => $filter['groupids'],
+				'preservekeys' => true
+			]);
+
+			$filter['groupids'] = array_filter($filter['groupids'], function($groupid) use ($groups) {
+				return array_key_exists($groupid, $groups);
+			});
+		}
+
+		return $filter;
+	}
+
+	/**
+	 * Clean and convert passed filter input fields from default values required for HTML presentation.
+	 *
+	 * @param array $input  Filter fields values.
+	 *
+	 * @return array
+	 */
+	protected function cleanInput(array $input): array {
+		if (array_key_exists('tags', $input) && $input['tags']) {
+			$input['tags'] = array_filter($input['tags'], function($tag) {
+				return !($tag['tag'] === '' && $tag['value'] === '');
+			});
+			$input['tags'] = array_values($input['tags']);
+		}
+
+		return $input;
+	}
 }
