@@ -114,12 +114,10 @@ class CControllerHousekeepingEdit extends CController {
 		];
 
 		if ($data['db_extension'] === ZBX_DB_EXTENSION_TIMESCALEDB) {
-			$dbversion_status = CSettingsHelper::getDbVersionStatus();
-
 			// Temporary state to show checkbox checked and disabled before the real state is detected.
 			$data['compression_not_detected'] = true;
 
-			foreach ($dbversion_status as $dbversion) {
+			foreach (CSettingsHelper::getDbVersionStatus() as $dbversion) {
 				if ($dbversion['database'] === ZBX_DB_EXTENSION_TIMESCALEDB) {
 					$data['timescaledb_min_version'] = $dbversion['min_version'];
 					$data['timescaledb_max_version'] = $dbversion['max_version'];
@@ -133,7 +131,7 @@ class CControllerHousekeepingEdit extends CController {
 					}
 
 					if ($data['compression_availability']) {
-						$data += CHousekeepingHelper::getWarnings($dbversion_status);
+						$data += CHousekeepingHelper::getWarnings();
 					}
 
 					break;
