@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -32,7 +32,8 @@ class CControllerMiscConfigUpdate extends CController {
 			'login_block' =>					'required|db config.login_block|time_unit '.implode(':', [30, SEC_PER_HOUR]),
 			'validate_uri_schemes' =>			'required|db config.validate_uri_schemes|in 0,1',
 			'uri_valid_schemes' =>				'db config.uri_valid_schemes',
-			'x_frame_options' =>				'required|db config.x_frame_options|not_empty',
+			'x_frame_header_enabled' =>			'required|in 0,1',
+			'x_frame_options' =>				'db config.x_frame_options',
 			'iframe_sandboxing_enabled' =>		'required|db config.iframe_sandboxing_enabled|in 0,1',
 			'iframe_sandboxing_exceptions' =>	'db config.iframe_sandboxing_exceptions',
 			'socket_timeout' =>					'required|db config.socket_timeout|time_unit '.implode(':', [1, 300]),
@@ -46,6 +47,14 @@ class CControllerMiscConfigUpdate extends CController {
 
 		$ret = $this->validateInput($fields);
 
+		if ($ret) {
+			if ($this->getInput('x_frame_header_enabled') == 1) {
+				$fields['x_frame_options'] = 'required|not_empty';
+			}
+
+			$ret = $this->validateInput($fields);
+		}
+
 		if (!$ret) {
 			switch ($this->getValidationError()) {
 				case self::VALIDATION_ERROR:
@@ -84,7 +93,6 @@ class CControllerMiscConfigUpdate extends CController {
 			CSettingsHelper::LOGIN_ATTEMPTS => $this->getInput('login_attempts'),
 			CSettingsHelper::LOGIN_BLOCK => $this->getInput('login_block'),
 			CSettingsHelper::VALIDATE_URI_SCHEMES => $this->getInput('validate_uri_schemes'),
-			CSettingsHelper::X_FRAME_OPTIONS => $this->getInput('x_frame_options'),
 			CSettingsHelper::IFRAME_SANDBOXING_ENABLED => $this->getInput('iframe_sandboxing_enabled'),
 			CSettingsHelper::SOCKET_TIMEOUT => $this->getInput('socket_timeout'),
 			CSettingsHelper::CONNECT_TIMEOUT => $this->getInput('connect_timeout'),
@@ -103,6 +111,10 @@ class CControllerMiscConfigUpdate extends CController {
 			);
 		}
 
+		$settings[CSettingsHelper::X_FRAME_OPTIONS] = $this->getInput('x_frame_header_enabled') == 1
+			? $this->getInput('x_frame_options')
+			: 'null';
+
 		if ($settings[CSettingsHelper::IFRAME_SANDBOXING_ENABLED] == 1) {
 			$settings[CSettingsHelper::IFRAME_SANDBOXING_EXCEPTIONS] = $this->getInput('iframe_sandboxing_exceptions',
 				DB::getSchema('config')['fields']['iframe_sandboxing_exceptions']['default']
