@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -247,8 +247,13 @@ class CControllerPopupItemTestEdit extends CControllerPopupItemTest {
 											}
 											break;
 
-										case CHistFunctionParser::PARAM_TYPE_PERIOD:
 										case CHistFunctionParser::PARAM_TYPE_QUOTED:
+											$match = CHistFunctionParser::unquoteParam($parameter['match']);
+											$texts_support_user_macros[] = $match;
+											$texts_support_lld_macros[] = $match;
+											break;
+
+										case CHistFunctionParser::PARAM_TYPE_PERIOD:
 										case CHistFunctionParser::PARAM_TYPE_UNQUOTED:
 											$texts_support_user_macros[] = $parameter['match'];
 											$texts_support_lld_macros[] = $parameter['match'] ;
