@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -447,11 +447,18 @@ class CControllerPopupItemTestSend extends CControllerPopupItemTest {
 							}
 						}
 						elseif ($step['type'] == ZBX_PREPROC_VALIDATE_NOT_SUPPORTED) {
-							$step['result'] = $preproc_test_data['value'];
+							unset($step['result']);
+						}
+						elseif (array_key_exists('truncated', $step) && $step['truncated']) {
+							$step['warning'] = _s('Result is truncated due to its size (%1$s).',
+								convertUnits(['value' => $step['original_size'], 'units' => 'B'])
+							);
 						}
 					}
 
-					unset($step['type'], $step['params'], $step['error_handler'], $step['error_handler_params']);
+					unset($step['type'], $step['params'], $step['error_handler'], $step['error_handler_params'],
+						$step['truncated'], $step['original_size']
+					);
 
 					// Latest executed step due to the error or end of preprocessing.
 					$test_outcome = $step + ['action' => ZBX_PREPROC_FAIL_DEFAULT];
@@ -470,6 +477,12 @@ class CControllerPopupItemTestSend extends CControllerPopupItemTest {
 							'result' => $result['result']
 						];
 
+						if (array_key_exists('truncated', $result) && $result['truncated']) {
+							$output['final']['warning'] = _s('Result is truncated due to its size (%1$s).',
+								convertUnits(['value' => $result['original_size'], 'units' => 'B'])
+							);
+						}
+
 						if ($valuemap) {
 							$output['mapped_value'] = CValueMapHelper::applyValueMap($preproc_test_data['value_type'],
 								$result['result'], $valuemap
