@@ -1,7 +1,7 @@
 <?php declare(strict_types = 0);
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -27,78 +27,88 @@ class CControllerUserroleEdit extends CControllerUserroleEditGeneral {
 	private $role;
 
 	protected function init(): void {
-		$this->disableSIDValidation();
+		$this->disableCsrfValidation();
 	}
 
 	protected function checkInput(): bool {
 		$fields = [
-			'roleid' => 								'db users.roleid',
-			'name' => 									'db role.name',
-			'type' => 									'in '.implode(',', [USER_TYPE_ZABBIX_USER, USER_TYPE_ZABBIX_ADMIN, USER_TYPE_SUPER_ADMIN]),
-			'ui_monitoring_dashboard' => 				'in 0,1',
-			'ui_monitoring_problems' => 				'in 0,1',
-			'ui_monitoring_hosts' => 					'in 0,1',
-			'ui_monitoring_latest_data' => 				'in 0,1',
-			'ui_monitoring_maps' => 					'in 0,1',
-			'ui_monitoring_discovery' => 				'in 0,1',
-			'ui_services_services' => 					'in 0,1',
-			'ui_services_actions' => 					'in 0,1',
-			'ui_services_sla' => 						'in 0,1',
-			'ui_services_sla_report' => 				'in 0,1',
-			'ui_inventory_overview' => 					'in 0,1',
-			'ui_inventory_hosts' => 					'in 0,1',
-			'ui_reports_system_info' => 				'in 0,1',
-			'ui_reports_scheduled_reports' => 			'in 0,1',
-			'ui_reports_availability_report' => 		'in 0,1',
-			'ui_reports_top_triggers' => 				'in 0,1',
-			'ui_reports_audit' => 						'in 0,1',
-			'ui_reports_action_log' => 					'in 0,1',
-			'ui_reports_notifications' => 				'in 0,1',
-			'ui_configuration_template_groups' => 		'in 0,1',
-			'ui_configuration_host_groups' => 			'in 0,1',
-			'ui_configuration_templates' => 			'in 0,1',
-			'ui_configuration_hosts' => 				'in 0,1',
-			'ui_configuration_maintenance' => 			'in 0,1',
-			'ui_configuration_actions' => 				'in 0,1',
-			'ui_configuration_event_correlation' => 	'in 0,1',
-			'ui_configuration_discovery' => 			'in 0,1',
-			'ui_administration_general' => 				'in 0,1',
-			'ui_administration_proxies' => 				'in 0,1',
-			'ui_administration_authentication' => 		'in 0,1',
-			'ui_administration_user_groups' => 			'in 0,1',
-			'ui_administration_user_roles' => 			'in 0,1',
-			'ui_administration_users' => 				'in 0,1',
-			'ui_administration_media_types' => 			'in 0,1',
-			'ui_administration_scripts' => 				'in 0,1',
-			'ui_administration_queue' => 				'in 0,1',
-			'actions_edit_dashboards' => 				'in 0,1',
-			'actions_edit_maps' => 						'in 0,1',
-			'actions_edit_maintenance' => 				'in 0,1',
-			'actions_acknowledge_problems' => 			'in 0,1',
-			'actions_close_problems' => 				'in 0,1',
-			'actions_change_severity' => 				'in 0,1',
-			'actions_add_problem_comments' => 			'in 0,1',
-			'actions_execute_scripts' => 				'in 0,1',
-			'actions_manage_api_tokens' => 				'in 0,1',
-			'actions_manage_scheduled_reports' => 		'in 0,1',
-			'actions_manage_sla' => 					'in 0,1',
-			'actions_invoke_execute_now' =>				'in 0,1',
-			'ui_default_access' => 						'in 0,1',
-			'modules_default_access' => 				'in 0,1',
-			'actions_default_access' => 				'in 0,1',
-			'modules' => 								'array',
-			'api_access' => 							'in 0,1',
-			'api_mode' => 								'in '.implode(',', [ZBX_ROLE_RULE_API_MODE_DENY, ZBX_ROLE_RULE_API_MODE_ALLOW]),
-			'api_methods' => 							'array',
-			'service_read_access' => 					'in '.implode(',', [CRoleHelper::SERVICES_ACCESS_NONE, CRoleHelper::SERVICES_ACCESS_ALL, CRoleHelper::SERVICES_ACCESS_LIST]),
-			'service_read_list' => 						'array_db services.serviceid',
-			'service_read_tag_tag' => 					'string',
-			'service_read_tag_value' => 				'string',
-			'service_write_access' => 					'in '.implode(',', [CRoleHelper::SERVICES_ACCESS_NONE, CRoleHelper::SERVICES_ACCESS_ALL, CRoleHelper::SERVICES_ACCESS_LIST]),
-			'service_write_list' => 					'array_db services.serviceid',
-			'service_write_tag_tag' => 					'string',
-			'service_write_tag_value' => 				'string',
-			'form_refresh' => 							'int32'
+			'roleid' => 									'db users.roleid',
+			'name' => 										'db role.name',
+			'type' => 										'in '.implode(',', [USER_TYPE_ZABBIX_USER, USER_TYPE_ZABBIX_ADMIN, USER_TYPE_SUPER_ADMIN]),
+			'ui_monitoring_dashboard' => 					'in 0,1',
+			'ui_monitoring_problems' => 					'in 0,1',
+			'ui_monitoring_hosts' => 						'in 0,1',
+			'ui_monitoring_latest_data' => 					'in 0,1',
+			'ui_monitoring_maps' => 						'in 0,1',
+			'ui_monitoring_discovery' => 					'in 0,1',
+			'ui_services_services' => 						'in 0,1',
+			'ui_services_sla' => 							'in 0,1',
+			'ui_services_sla_report' => 					'in 0,1',
+			'ui_inventory_overview' => 						'in 0,1',
+			'ui_inventory_hosts' => 						'in 0,1',
+			'ui_reports_system_info' => 					'in 0,1',
+			'ui_reports_scheduled_reports' => 				'in 0,1',
+			'ui_reports_availability_report' => 			'in 0,1',
+			'ui_reports_top_triggers' => 					'in 0,1',
+			'ui_reports_audit' => 							'in 0,1',
+			'ui_reports_action_log' => 						'in 0,1',
+			'ui_reports_notifications' => 					'in 0,1',
+			'ui_configuration_template_groups' => 			'in 0,1',
+			'ui_configuration_host_groups' => 				'in 0,1',
+			'ui_configuration_templates' => 				'in 0,1',
+			'ui_configuration_hosts' => 					'in 0,1',
+			'ui_configuration_maintenance' => 				'in 0,1',
+			'ui_configuration_trigger_actions' => 			'in 0,1',
+			'ui_configuration_service_actions' => 			'in 0,1',
+			'ui_configuration_discovery_actions' => 		'in 0,1',
+			'ui_configuration_autoregistration_actions' => 	'in 0,1',
+			'ui_configuration_internal_actions' => 			'in 0,1',
+			'ui_configuration_event_correlation' => 		'in 0,1',
+			'ui_configuration_discovery' => 				'in 0,1',
+			'ui_administration_general' => 					'in 0,1',
+			'ui_administration_audit_log' =>				'in 0,1',
+			'ui_administration_housekeeping' => 			'in 0,1',
+			'ui_administration_proxies' => 					'in 0,1',
+			'ui_administration_macros' => 					'in 0,1',
+			'ui_administration_authentication' => 			'in 0,1',
+			'ui_administration_user_groups' => 				'in 0,1',
+			'ui_administration_user_roles' => 				'in 0,1',
+			'ui_administration_users' => 					'in 0,1',
+			'ui_administration_api_tokens' => 				'in 0,1',
+			'ui_administration_media_types' => 				'in 0,1',
+			'ui_administration_scripts' => 					'in 0,1',
+			'ui_administration_queue' => 					'in 0,1',
+			'actions_edit_dashboards' => 					'in 0,1',
+			'actions_edit_maps' => 							'in 0,1',
+			'actions_edit_maintenance' => 					'in 0,1',
+			'actions_acknowledge_problems' => 				'in 0,1',
+			'actions_close_problems' => 					'in 0,1',
+			'actions_suppress_problems' =>					'in 0,1',
+			'actions_change_severity' => 					'in 0,1',
+			'actions_add_problem_comments' => 				'in 0,1',
+			'actions_execute_scripts' => 					'in 0,1',
+			'actions_manage_api_tokens' => 					'in 0,1',
+			'actions_manage_scheduled_reports' => 			'in 0,1',
+			'actions_manage_sla' => 						'in 0,1',
+			'actions_invoke_execute_now' =>					'in 0,1',
+			'actions_change_problem_ranking' =>				'in 0,1',
+			'ui_default_access' => 							'in 0,1',
+			'modules_default_access' => 					'in 0,1',
+			'actions_default_access' => 					'in 0,1',
+			'modules' => 									'array',
+			'api_access' => 								'in 0,1',
+			'api_mode' => 									'in '.implode(',', [ZBX_ROLE_RULE_API_MODE_DENY, ZBX_ROLE_RULE_API_MODE_ALLOW]),
+			'api_methods' => 								'array',
+			'service_read_access' => 						'in '.implode(',', [CRoleHelper::SERVICES_ACCESS_NONE, CRoleHelper::SERVICES_ACCESS_ALL, CRoleHelper::SERVICES_ACCESS_LIST]),
+			'service_read_list' => 							'array_db services.serviceid',
+			'service_read_tag_tag' => 						'string',
+			'service_read_tag_value' => 					'string',
+			'service_write_access' => 						'in '.implode(',', [CRoleHelper::SERVICES_ACCESS_NONE, CRoleHelper::SERVICES_ACCESS_ALL, CRoleHelper::SERVICES_ACCESS_LIST]),
+			'service_write_list' => 						'array_db services.serviceid',
+			'service_write_tag_tag' => 						'string',
+			'service_write_tag_value' => 					'string',
+			'form_refresh' => 								'int32',
+			'super_admin_role_clone' =>						'in 1'
 		];
 
 		$ret = $this->validateInput($fields);
@@ -141,39 +151,86 @@ class CControllerUserroleEdit extends CControllerUserroleEditGeneral {
 	protected function doAction(): void {
 		$db_defaults = DB::getDefaults('role');
 
-		if ($this->hasInput('form_refresh')) {
-			$data = $this->getFormData([
-				'roleid' => null,
-				'readonly' => (bool) $db_defaults['readonly'],
-				'is_own_role' => $this->getInput('roleid', 0) == CWebUser::$data['roleid'],
-				'rules' => $this->getRulesDefaults((int) $this->getInput('type'))
-			]);
-		}
-		elseif ($this->role !== null) {
+		if ($this->hasInput('super_admin_role_clone')) {
 			$data = [
-				'roleid' => $this->role['roleid'],
-				'name' => $this->role['name'],
-				'type' => $this->role['type'],
-				'readonly' => (bool) $this->role['readonly'],
-				'is_own_role' => $this->role['roleid'] == CWebUser::$data['roleid'],
+				'roleid' => null,
+				'name' => $this->getInput('name', ''),
+				'type' => $this->getInput('type', USER_TYPE_SUPER_ADMIN),
+				'readonly' => (bool) $db_defaults['readonly'],
+				'is_own_role' => false,
 				'rules' => array_merge(
-					$this->getRulesDefaults((int) $this->role['type']),
-					$this->getRules($this->role['roleid'])
+					$this->getRulesDefaults((int) $this->getInput('type', USER_TYPE_SUPER_ADMIN)),
+					$this->getRulesByRoleid(USER_TYPE_SUPER_ADMIN)
 				)
 			];
 		}
-		else {
+		elseif ($this->role === null) {
 			$data = [
 				'roleid' => null,
-				'name' => $db_defaults['name'],
-				'type' => $db_defaults['type'],
 				'readonly' => (bool) $db_defaults['readonly'],
-				'is_own_role' => false,
-				'rules' => $this->getRulesDefaults((int) $db_defaults['type'])
+				'is_own_role' => false
 			];
+
+			if (!$this->hasInput('form_refresh')) {
+				$data += [
+					'name' => $db_defaults['name'],
+					'type' => $db_defaults['type'],
+					'rules' => $this->getRulesDefaults((int) $db_defaults['type'])
+				];
+			}
+			else {
+				$data += [
+					'name' => $this->getInput('name', $db_defaults['name']),
+					'type' => $this->getInput('type', USER_TYPE_ZABBIX_USER),
+					'rules' => array_merge(
+						$this->getRulesDefaults((int) $this->getInput('type', USER_TYPE_ZABBIX_USER)),
+						$this->getRules($this->getRulesInput($this->getInput('type', USER_TYPE_ZABBIX_USER)))
+					)
+				];
+			}
+		}
+		else {
+			$data = [
+				'roleid' => $this->role['roleid'],
+				'readonly' => (bool) $this->role['readonly'],
+				'is_own_role' => $this->role['roleid'] == CWebUser::$data['roleid']
+			];
+
+			if (!$this->hasInput('form_refresh')) {
+				$data += [
+					'name' => $this->role['name'],
+					'type' => $this->role['type'],
+					'rules' => array_merge(
+						$this->getRulesDefaults((int) $this->role['type']),
+						$this->getRulesByRoleid($this->role['roleid'])
+					)
+				];
+			}
+			else {
+				$data += [
+					'name' => $this->getInput('name', $db_defaults['name']),
+					'type' => $this->getInput('type', $this->role['type']),
+					'rules' => array_merge(
+						$this->getRulesDefaults((int) $this->getInput('type', $this->role['type'])),
+						$this->getRules($this->getRulesInput($this->getInput('type', $this->role['type'])))
+					)
+				];
+			}
 		}
 
-		$data['labels'] = $this->getLabels();
+		$db_modules = API::Module()->get([
+			'output' => ['moduleid', 'relative_path', 'status']
+		]);
+
+		$disabled_modules = array_filter($db_modules,
+			static function(array $db_module): bool {
+				return $db_module['status'] == MODULE_STATUS_DISABLED;
+			}
+		);
+
+		$data['disabled_moduleids'] = array_column($disabled_modules, 'moduleid', 'moduleid');
+
+		$data['labels'] = $this->getLabels($db_modules);
 
 		$data['rules']['service_read_list'] = API::Service()->get([
 			'output' => ['serviceid', 'name'],
@@ -185,6 +242,8 @@ class CControllerUserroleEdit extends CControllerUserroleEditGeneral {
 			'serviceids' => array_column($data['rules']['service_write_list'], 'serviceid')
 		]);
 
+		$data['form_refresh'] = $this->getInput('form_refresh', 0);
+
 		$response = new CControllerResponseData($data);
 		$response->setTitle(_('Configuration of user roles'));
 		$this->setResponse($response);
@@ -284,10 +343,7 @@ class CControllerUserroleEdit extends CControllerUserroleEditGeneral {
 		return $data;
 	}
 
-	/**
-	 * @throws APIException
-	 */
-	private function getLabels(): array {
+	private function getLabels(array $db_modules): array {
 		$labels = [
 			'sections' => CRoleHelper::getUiSectionsLabels(USER_TYPE_SUPER_ADMIN),
 			'actions' => CRoleHelper::getActionsLabels(USER_TYPE_SUPER_ADMIN)
@@ -297,23 +353,21 @@ class CControllerUserroleEdit extends CControllerUserroleEditGeneral {
 			$labels['rules'][$section] = CRoleHelper::getUiSectionRulesLabels($section, USER_TYPE_SUPER_ADMIN);
 		}
 
-		$db_modules = API::Module()->get([
-			'output' => ['moduleid', 'relative_path'],
-			'filter' => [
-				'status' => MODULE_STATUS_ENABLED
-			]
-		]);
+		$labels['modules'] = [];
 
 		if ($db_modules) {
-			$module_manager = new CModuleManager(APP::ModuleManager()->getModulesDir());
-			foreach ($db_modules as $module) {
-				$manifest = $module_manager->addModule($module['relative_path']);
-				$labels['modules'][$module['moduleid']] = $manifest['name'];
+			$module_manager = new CModuleManager(APP::getRootDir());
+
+			foreach ($db_modules as $db_module) {
+				$manifest = $module_manager->addModule($db_module['relative_path']);
+
+				if ($manifest !== null) {
+					$labels['modules'][$db_module['moduleid']] = $manifest['name'];
+				}
 			}
 		}
-		else {
-			$labels['modules'] = [];
-		}
+
+		natcasesort($labels['modules']);
 
 		return $labels;
 	}
@@ -341,7 +395,7 @@ class CControllerUserroleEdit extends CControllerUserroleEditGeneral {
 	/**
 	 * @throws APIException
 	 */
-	private function getRules(string $roleid): array {
+	private function getRulesByRoleid(string $roleid): array {
 		$roles = API::Role()->get([
 			'output' => ['roleid'],
 			'selectRules' => ['ui', 'ui.default_access', 'modules', 'modules.default_access', 'api', 'api.access',
@@ -351,45 +405,47 @@ class CControllerUserroleEdit extends CControllerUserroleEditGeneral {
 			'roleids' => $roleid
 		]);
 
-		$role = $roles[0];
+		return $this->getRules($roles[0]['rules']);
+	}
 
+	private function getRules(array $input): array {
 		$rules = [];
 
-		foreach ($role['rules']['ui'] as $rule) {
+		foreach ($input['ui'] as $rule) {
 			$rules['ui']['ui.'.$rule['name']] = $rule['status'];
 		}
 
-		if ($role['rules']['services.read.mode'] == ZBX_ROLE_RULE_SERVICES_ACCESS_ALL) {
+		if ($input['services.read.mode'] == ZBX_ROLE_RULE_SERVICES_ACCESS_ALL) {
 			$rules['service_read_access'] = CRoleHelper::SERVICES_ACCESS_ALL;
 		}
-		elseif ($role['rules']['services.read.list'] || $role['rules']['services.read.tag']['tag'] !== '') {
+		elseif ($input['services.read.list'] || $input['services.read.tag']['tag'] !== '') {
 			$rules['service_read_access'] = CRoleHelper::SERVICES_ACCESS_LIST;
 		}
 		else {
 			$rules['service_read_access'] = CRoleHelper::SERVICES_ACCESS_NONE;
 		}
 
-		$rules['service_read_list'] = $role['rules']['services.read.list'];
-		$rules['service_read_tag'] = $role['rules']['services.read.tag'];
+		$rules['service_read_list'] = $input['services.read.list'];
+		$rules['service_read_tag'] = $input['services.read.tag'];
 
-		if ($role['rules']['services.write.mode'] == ZBX_ROLE_RULE_SERVICES_ACCESS_ALL) {
+		if ($input['services.write.mode'] == ZBX_ROLE_RULE_SERVICES_ACCESS_ALL) {
 			$rules['service_write_access'] = CRoleHelper::SERVICES_ACCESS_ALL;
 		}
-		elseif ($role['rules']['services.write.list'] || $role['rules']['services.write.tag']['tag'] !== '') {
+		elseif ($input['services.write.list'] || $input['services.write.tag']['tag'] !== '') {
 			$rules['service_write_access'] = CRoleHelper::SERVICES_ACCESS_LIST;
 		}
 		else {
 			$rules['service_write_access'] = CRoleHelper::SERVICES_ACCESS_NONE;
 		}
 
-		$rules['service_write_list'] = $role['rules']['services.write.list'];
-		$rules['service_write_tag'] = $role['rules']['services.write.tag'];
+		$rules['service_write_list'] = $input['services.write.list'];
+		$rules['service_write_tag'] = $input['services.write.tag'];
 
-		foreach ($role['rules']['modules'] as $rule) {
+		foreach ($input['modules'] as $rule) {
 			$rules['modules'][$rule['moduleid']] = $rule['status'];
 		}
 
-		if ($role['rules']['api']) {
+		if ($input['api']) {
 			$rules['api'] = array_map(
 				static function (string $method): array {
 					return [
@@ -397,19 +453,19 @@ class CControllerUserroleEdit extends CControllerUserroleEditGeneral {
 						'name' => $method
 					];
 				},
-				$role['rules']['api']
+				$input['api']
 			);
 		}
 
-		foreach ($role['rules']['actions'] as $rule) {
+		foreach ($input['actions'] as $rule) {
 			$rules['actions']['actions.'.$rule['name']] = $rule['status'];
 		}
 
-		$rules['ui.default_access'] = $role['rules']['ui.default_access'];
-		$rules['modules.default_access'] = $role['rules']['modules.default_access'];
-		$rules['api.access'] = $role['rules']['api.access'];
-		$rules['api.mode'] = $role['rules']['api.mode'];
-		$rules['actions.default_access'] = $role['rules']['actions.default_access'];
+		$rules['ui.default_access'] = $input['ui.default_access'];
+		$rules['modules.default_access'] = $input['modules.default_access'];
+		$rules['api.access'] = $input['api.access'];
+		$rules['api.mode'] = $input['api.mode'];
+		$rules['actions.default_access'] = $input['actions.default_access'];
 
 		return $rules;
 	}
