@@ -1,7 +1,7 @@
 <?php declare(strict_types = 0);
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -31,9 +31,9 @@ if ($data['uncheck']) {
 	uncheckTableRows('hosts');
 }
 
-$widget = (new CWidget())
+$html_page = (new CHtmlPage())
 	->setTitle(_('Hosts'))
-	->setDocUrl(CDocHelper::getUrl(CDocHelper::CONFIGURATION_HOST_LIST))
+	->setDocUrl(CDocHelper::getUrl(CDocHelper::DATA_COLLECTION_HOST_LIST))
 	->setControls((new CTag('nav', true, (new CList())
 			->addItem(
 				(new CSimpleButton(_('Create host')))
@@ -42,7 +42,13 @@ $widget = (new CWidget())
 			->addItem(
 				(new CButton('form', _('Import')))
 					->onClick(
-						'return PopUp("popup.import", {rules_preset: "host"}, {dialogue_class: "modal-popup-generic"});'
+						'return PopUp("popup.import", {
+							rules_preset: "host", '.
+							CCsrfTokenHelper::CSRF_TOKEN_NAME.': "'. CCsrfTokenHelper::get('import').
+						'"}, {
+							dialogueid: "popup_import",
+							dialogue_class: "modal-popup-generic"
+						});'
 					)
 					->removeId()
 			)
@@ -125,6 +131,16 @@ $filter = (new CFilter())
 			]),
 		(new CFormGrid())
 			->addClass(CFormGrid::ZBX_STYLE_FORM_GRID_LABEL_WIDTH_TRUE)
+			->addItem([
+				new CLabel(_('Status'), 'filter_status'),
+				new CFormField(
+					(new CRadioButtonList('filter_status', (int) $data['filter']['status']))
+						->addValue(_('Any'), -1)
+						->addValue(_('Enabled'), HOST_STATUS_MONITORED)
+						->addValue(_('Disabled'), HOST_STATUS_NOT_MONITORED)
+						->setModern(true)
+				)
+			])
 			->addItem([
 				new CLabel(_('Monitored by'), 'filter_monitored_by'),
 				new CFormField(
@@ -166,7 +182,7 @@ $filter = (new CFilter())
 			])
 	]);
 
-$widget->addItem($filter);
+$html_page->addItem($filter);
 
 // table hosts
 $form = (new CForm())->setName('hosts');
@@ -200,6 +216,7 @@ $table = (new CTableInfo())
 	]);
 
 $current_time = time();
+$csrf_token_massupdate = CCsrfTokenHelper::get('host');
 
 foreach ($data['hosts'] as $host) {
 	// Select an interface from the list with highest priority.
@@ -245,7 +262,7 @@ foreach ($data['hosts'] as $host) {
 		$description[] = NAME_DELIMITER;
 	}
 
-	$description[] = (new CLink(CHtml::encode($host['name']),
+	$description[] = (new CLink($host['name'],
 		(new CUrl('zabbix.php'))
 			->setArgument('action', 'host.edit')
 			->setArgument('hostid', $host['hostid'])
@@ -260,7 +277,7 @@ foreach ($data['hosts'] as $host) {
 		->setArgument('visible[status]', 1)
 		->setArgument('update', 1)
 		->setArgument('backurl',
-			(new CUrl('zabbix.php', false))
+			(new CUrl('zabbix.php'))
 				->setArgument('action', 'host.list')
 				->setArgument('page', CPagerHelper::loadPage('host.list', null))
 				->getUrl()
@@ -284,7 +301,7 @@ foreach ($data['hosts'] as $host) {
 			->addClass(ZBX_STYLE_LINK_ACTION)
 			->addClass(ZBX_STYLE_GREEN)
 			->addConfirmation(_('Disable host?'))
-			->addSID();
+			->addCsrfToken($csrf_token_massupdate);
 	}
 	else {
 		$status_toggle_url->setArgument('status', HOST_STATUS_MONITORED);
@@ -292,7 +309,7 @@ foreach ($data['hosts'] as $host) {
 			->addClass(ZBX_STYLE_LINK_ACTION)
 			->addClass(ZBX_STYLE_RED)
 			->addConfirmation(_('Enable host?'))
-			->addSID();
+			->addCsrfToken($csrf_token_massupdate);
 	}
 
 	if ($maintenance_icon) {
@@ -308,7 +325,7 @@ foreach ($data['hosts'] as $host) {
 		$i++;
 
 		if ($i > $data['config']['max_in_table']) {
-			$hostTemplates[] = ' &hellip;';
+			$hostTemplates[] = [' ', HELLIP()];
 
 			break;
 		}
@@ -316,7 +333,7 @@ foreach ($data['hosts'] as $host) {
 		if (array_key_exists($template['templateid'], $data['writable_templates'])
 				&& $data['allowed_ui_conf_templates']) {
 			$caption = [
-				(new CLink(CHtml::encode($template['name']),
+				(new CLink($template['name'],
 					(new CUrl('templates.php'))
 						->setArgument('form', 'update')
 						->setArgument('templateid', $template['templateid'])
@@ -327,7 +344,7 @@ foreach ($data['hosts'] as $host) {
 		}
 		else {
 			$caption = [
-				(new CSpan(CHtml::encode($template['name'])))->addClass(ZBX_STYLE_GREY)
+				(new CSpan($template['name']))->addClass(ZBX_STYLE_GREY)
 			];
 		}
 
@@ -341,7 +358,7 @@ foreach ($data['hosts'] as $host) {
 			foreach ($parent_templates as $parent_template) {
 				if (array_key_exists($parent_template['templateid'], $data['writable_templates'])
 						&& $data['allowed_ui_conf_templates']) {
-					$caption[] = (new CLink(CHtml::encode($parent_template['name']),
+					$caption[] = (new CLink($parent_template['name'],
 						(new CUrl('templates.php'))
 							->setArgument('form', 'update')
 							->setArgument('templateid', $parent_template['templateid'])
@@ -350,7 +367,7 @@ foreach ($data['hosts'] as $host) {
 						->addClass(ZBX_STYLE_GREY);
 				}
 				else {
-					$caption[] = (new CSpan(CHtml::encode($parent_template['name'])))->addClass(ZBX_STYLE_GREY);
+					$caption[] = (new CSpan($parent_template['name']))->addClass(ZBX_STYLE_GREY);
 				}
 
 				$caption[] = ', ';
@@ -481,7 +498,7 @@ foreach ($data['hosts'] as $host) {
 		$monitored_by,
 		$hostTemplates,
 		$toggle_status_link,
-		getHostAvailabilityTable($host['interfaces']),
+		getHostAvailabilityTable($host['interfaces'], $host['has_passive_checks']),
 		$encryption,
 		makeInformationList($info_icons),
 		$data['tags'][$host['hostid']]
@@ -490,10 +507,11 @@ foreach ($data['hosts'] as $host) {
 
 $status_toggle_url =  (new CUrl('zabbix.php'))
 	->setArgument('action', 'popup.massupdate.host')
+	->setArgument(CCsrfTokenHelper::CSRF_TOKEN_NAME, $csrf_token_massupdate)
 	->setArgument('visible[status]', 1)
 	->setArgument('update', 1)
 	->setArgument('backurl',
-		(new CUrl('zabbix.php', false))
+		(new CUrl('zabbix.php'))
 			->setArgument('action', 'host.list')
 			->setArgument('page', CPagerHelper::loadPage('host.list', null))
 			->getUrl()
@@ -526,7 +544,9 @@ $form->addItem([
 		'popup.massupdate.host' => [
 			'content' => (new CButton('', _('Mass update')))
 				->onClick(
-					"openMassupdatePopup('popup.massupdate.host', {}, {
+					"openMassupdatePopup('popup.massupdate.host', {".
+						CCsrfTokenHelper::CSRF_TOKEN_NAME.": '".$csrf_token_massupdate.
+					"'}, {
 						dialogue_class: 'modal-popup-static',
 						trigger_element: this
 					});"
@@ -545,7 +565,7 @@ $form->addItem([
 	], 'hosts')
 ]);
 
-$widget
+$html_page
 	->addItem($form)
 	->show();
 
