@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
  */
 
 $form = (new CForm())
-	->cleanItems()
+	->addItem((new CVar(CCsrfTokenHelper::CSRF_TOKEN_NAME, CCsrfTokenHelper::get('acknowledge')))->removeId())
 	->setId('acknowledge_form')
 	->addVar('action', 'popup.acknowledge.create')
 	->addVar('eventids', $data['eventids']);
@@ -68,7 +68,8 @@ $form_list
 			->setAttribute('style', 'min-width: '.ZBX_TEXTAREA_BIG_WIDTH.'px;')
 			->addClass(ZBX_STYLE_TABLE_FORMS_SEPARATOR)
 	)
-	->addRow(_('Change severity'),
+	->addRow(
+		new CLabel(_('Change severity'), 'change_severity'),
 		(new CList([
 			(new CCheckBox('change_severity', ZBX_PROBLEM_UPDATE_SEVERITY))
 				->onClick('javascript: jQuery("#severity input").attr("disabled", this.checked ? false : true)')
@@ -77,10 +78,43 @@ $form_list
 			(new CSeverity('severity', (int) $data['severity'], $data['change_severity']))
 		]))
 			->addClass(ZBX_STYLE_HOR_LIST)
+	)
+	->addRow(
+		new CLabel([_('Suppress'),
+			makeHelpIcon(_('Manual problem suppression. Date-time input accepts relative and absolute time format.'))
+		], 'suppress_problem'),
+		(new CList([
+			(new CCheckBox('suppress_problem', ZBX_PROBLEM_UPDATE_SUPPRESS))
+				->setChecked($data['suppress_problem'])
+				->setEnabled($data['allowed_suppress'] && $data['problem_can_be_suppressed']),
+			(new CRadioButtonList('suppress_time_option', ZBX_PROBLEM_SUPPRESS_TIME_DEFINITE))
+				->addValue(_('Indefinitely'), ZBX_PROBLEM_SUPPRESS_TIME_INDEFINITE)
+				->addValue(_('Until'), ZBX_PROBLEM_SUPPRESS_TIME_DEFINITE)
+				->setEnabled(false)
+				->setModern(true),
+			(new CDateSelector('suppress_until_problem', $data['suppress_until_problem']))
+				->setDateFormat(ZBX_FULL_DATE_TIME)
+				->setPlaceholder(_($data['suppress_until_problem']))
+				->setAriaRequired()
+				->setEnabled(false)
+		]))->addClass(ZBX_STYLE_HOR_LIST)
+	)
+	->addRow(
+		new CLabel([_('Unsuppress'), makeHelpIcon(_('Deactivates manual suppression.'))], 'unsuppress_problem'),
+		(new CList([
+			(new CCheckBox('unsuppress_problem', ZBX_PROBLEM_UPDATE_UNSUPPRESS))
+				->setChecked($data['unsuppress_problem'])
+				->setEnabled($data['allowed_suppress'] && $data['problem_can_be_unsuppressed'])
+		]))->addClass(ZBX_STYLE_HOR_LIST)
 	);
 
 if ($data['has_unack_events']) {
-	$form_list->addRow(_('Acknowledge'),
+	$form_list->addRow(
+		new CLabel([_('Acknowledge'),
+			makeHelpIcon(
+				_('Confirms the problem is noticed (acknowledging user will be recorded). Status change triggers action update operation.')
+			)
+		], 'acknowledge_problem'),
 		(new CCheckBox('acknowledge_problem', ZBX_PROBLEM_UPDATE_ACKNOWLEDGE))
 			->onChange("$('#unacknowledge_problem').prop('disabled', this.checked)")
 			->setEnabled($data['allowed_acknowledge'])
@@ -88,7 +122,8 @@ if ($data['has_unack_events']) {
 }
 
 if ($data['has_ack_events']) {
-	$form_list->addRow(_('Unacknowledge'),
+	$form_list->addRow(
+		new CLabel([_('Unacknowledge'), makeHelpIcon(_('Undo problem acknowledgement.'))], 'unacknowledge_problem'),
 		(new CCheckBox('unacknowledge_problem', ZBX_PROBLEM_UPDATE_UNACKNOWLEDGE))
 			->onChange("$('#acknowledge_problem').prop('disabled', this.checked)")
 			->setEnabled($data['allowed_acknowledge'])
@@ -96,6 +131,13 @@ if ($data['has_ack_events']) {
 }
 
 $form_list
+	->addRow(
+		new CLabel([_('Convert to cause'),
+			makeHelpIcon(_('Converts a symptom event back to cause event'))
+		], 'change_rank'),
+		(new CCheckBox('change_rank', ZBX_PROBLEM_UPDATE_RANK_TO_CAUSE))
+			->setEnabled($data['allowed_change_problem_ranking'] && $data['problem_can_change_rank'])
+	)
 	->addRow(_('Close problem'),
 		(new CCheckBox('close_problem', ZBX_PROBLEM_UPDATE_CLOSE))
 			->setChecked($data['close_problem'])
@@ -109,6 +151,7 @@ $form->addItem($form_list);
 
 $output = [
 	'header' => $data['title'],
+	'doc_url' => CDocHelper::getUrl(CDocHelper::POPUP_ACKNOWLEDGMENT_EDIT),
 	'body' => (new CDiv([$data['errors'], $form]))->toString(),
 	'buttons' => [
 		[
@@ -116,10 +159,11 @@ $output = [
 			'class' => '',
 			'keepOpen' => true,
 			'isSubmit' => true,
-			'action' => 'return submitAcknowledge(overlay);'
+			'action' => 'update_problem_popup.submitAcknowledge(overlay);'
 		]
 	],
-	'script_inline' => $this->readJsFile('popup.acknowledge.edit.js.php')
+	'script_inline' => $this->readJsFile('popup.acknowledge.edit.js.php').
+		'update_problem_popup.init();'
 ];
 
 if ($data['user']['debug_mode'] == GROUP_DEBUG_MODE_ENABLED) {
