@@ -1,7 +1,7 @@
 <?php declare(strict_types = 0);
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@
 
 // create form
 $form = (new CForm())
+	->addItem((new CVar(CCsrfTokenHelper::CSRF_TOKEN_NAME, CCsrfTokenHelper::get('host')))->removeId())
 	->setId('massupdate-form')
 	->addVar('action', 'popup.massupdate.host')
 	->addVar('hostids', $data['hostids'], 'ids')
@@ -35,15 +36,17 @@ $form = (new CForm())
 
 $host_tab = new CFormList('hostFormList');
 
-$link_templates = (new CTable())
-	->addRow(
+$host_tab->addRow(
+	(new CVisibilityBox('visible[templates]', 'linked-templates-field', _('Original')))
+		->setLabel(_('Link templates'))
+		->setAttribute('autofocus', 'autofocus'),
+	(new CDiv([
 		(new CRadioButtonList('mass_action_tpls', ZBX_ACTION_ADD))
 			->addValue(_('Link'), ZBX_ACTION_ADD)
 			->addValue(_('Replace'), ZBX_ACTION_REPLACE)
 			->addValue(_('Unlink'), ZBX_ACTION_REMOVE)
 			->setModern(true)
-	)
-	->addRow([
+			->addStyle('margin-bottom: 5px;'),
 		(new CMultiSelect([
 			'name' => 'templates[]',
 			'object_name' => 'templates',
@@ -57,26 +60,17 @@ $link_templates = (new CTable())
 					'dstfld1' => 'templates_'
 				]
 			]
-		]))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
-	])
-	->addRow([
+		]))
+			->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
+			->addStyle('margin-bottom: 5px;'),
 		(new CList())
 			->addClass(ZBX_STYLE_LIST_CHECK_RADIO)
 			->addItem((new CCheckBox('mass_clear_tpls'))->setLabel(_('Clear when unlinking')))
-	]);
-
-$host_tab->addRow(
-	(new CVisibilityBox('visible[templates]', 'linked-templates-div', _('Original')))
-		->setLabel(_('Link templates')),
-	(new CDiv($link_templates))
-		->setId('linked-templates-div')
-		->addStyle('margin-top: -5px;')
+	]))->setId('linked-templates-field')
 );
 
 $host_tab->addRow(
-	(new CVisibilityBox('visible[groups]', 'groups-div', _('Original')))
-		->setLabel(_('Host groups'))
-		->setAttribute('autofocus', 'autofocus'),
+	(new CVisibilityBox('visible[groups]', 'groups-field', _('Original')))->setLabel(_('Host groups')),
 	(new CDiv([
 		(new CRadioButtonList('mass_update_groups', ZBX_ACTION_ADD))
 			->addValue(_('Add'), ZBX_ACTION_ADD)
@@ -99,7 +93,7 @@ $host_tab->addRow(
 				]
 			]
 		]))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
-	]))->setId('groups-div')
+	]))->setId('groups-field')
 );
 
 // append description to form list
@@ -116,8 +110,8 @@ $proxy_select = (new CSelect('proxy_hostid'))
 	->setValue(0)
 	->addOption(new CSelectOption(0, _('(no proxy)')));
 
-foreach ($data['proxies'] as $proxie) {
-	$proxy_select->addOption(new CSelectOption($proxie['proxyid'], $proxie['host']));
+foreach ($data['proxies'] as $proxy) {
+	$proxy_select->addOption(new CSelectOption($proxy['proxyid'], $proxy['host']));
 }
 
 $host_tab->addRow(
@@ -157,13 +151,13 @@ $ipmi_tab->addRow(
 )
 ->addRow(
 	(new CVisibilityBox('visible[ipmi_username]', 'ipmi_username', _('Original')))->setLabel(_('Username')),
-	(new CTextBox('ipmi_username', ''))
+	(new CTextBox('ipmi_username', '', false, DB::getFieldLength('hosts', 'ipmi_username')))
 		->setWidth(ZBX_TEXTAREA_SMALL_WIDTH)
 		->disableAutocomplete()
 )
 ->addRow(
 	(new CVisibilityBox('visible[ipmi_password]', 'ipmi_password', _('Original')))->setLabel(_('Password')),
-	(new CTextBox('ipmi_password', ''))
+	(new CTextBox('ipmi_password', '', false, DB::getFieldLength('hosts', 'ipmi_password')))
 		->setWidth(ZBX_TEXTAREA_SMALL_WIDTH)
 		->disableAutocomplete()
 );
@@ -172,21 +166,20 @@ $inventory_tab = new CFormList('inventoryFormList');
 
 // append inventories to form list
 $inventory_tab->addRow(
-	(new CVisibilityBox('visible[inventory_mode]', 'inventory_mode_div', _('Original')))->setLabel(_('Inventory mode')),
-	(new CDiv(
-		(new CRadioButtonList('inventory_mode', HOST_INVENTORY_DISABLED))
-			->addValue(_('Disabled'), HOST_INVENTORY_DISABLED)
-			->addValue(_('Manual'), HOST_INVENTORY_MANUAL)
-			->addValue(_('Automatic'), HOST_INVENTORY_AUTOMATIC)
-			->setModern(true)
-	))->setId('inventory_mode_div')
+	(new CVisibilityBox('visible[inventory_mode]', 'inventory_mode', _('Original')))->setLabel(_('Inventory mode')),
+	(new CRadioButtonList('inventory_mode', HOST_INVENTORY_DISABLED))
+		->setId('inventory_mode')
+		->addValue(_('Disabled'), HOST_INVENTORY_DISABLED)
+		->addValue(_('Manual'), HOST_INVENTORY_MANUAL)
+		->addValue(_('Automatic'), HOST_INVENTORY_AUTOMATIC)
+		->setModern(true)
 );
 
 $tags_tab = new CFormList('tagsFormList');
 
 // append tags table to form list
 $tags_tab->addRow(
-	(new CVisibilityBox('visible[tags]', 'tags-div', _('Original')))->setLabel(_('Tags')),
+	(new CVisibilityBox('visible[tags]', 'tags-field', _('Original')))->setLabel(_('Tags')),
 	(new CDiv([
 		(new CRadioButtonList('mass_update_tags', ZBX_ACTION_ADD))
 			->addValue(_('Add'), ZBX_ACTION_ADD)
@@ -197,7 +190,7 @@ $tags_tab->addRow(
 		renderTagTable([['tag' => '', 'value' => '']])
 			->setHeader([_('Name'), _('Value'), _('Action')])
 			->addClass('tags-table')
-	]))->setId('tags-div')
+	]))->setId('tags-field')
 );
 
 $hostInventoryTable = DB::getSchema('host_inventory');
@@ -221,7 +214,7 @@ foreach ($data['inventories'] as $field => $fieldInfo) {
 
 $encryption_tab = new CFormList('encryption');
 
-$encryption_table = (new CFormList('encryption'))
+$encryption_table = (new CFormList('encryption-field'))
 	->addRow(_('Connections to host'),
 		(new CRadioButtonList('tls_connect', HOST_ENCRYPTION_NONE))
 			->addValue(_('No encryption'), HOST_ENCRYPTION_NONE)
@@ -269,10 +262,8 @@ $encryption_table = (new CFormList('encryption'))
 	);
 
 $encryption_tab->addRow(
-	(new CVisibilityBox('visible[encryption]', 'encryption_div', _('Original')))->setLabel(_('Connections')),
-	(new CDiv($encryption_table))
-		->setId('encryption_div')
-		->addStyle('margin-top: -5px;')
+	(new CVisibilityBox('visible[encryption]', 'encryption-field', _('Original')))->setLabel(_('Connections')),
+	$encryption_table->addStyle('margin-top: -5px;')
 );
 
 // append tabs to form
