@@ -1,7 +1,7 @@
 <?php declare(strict_types = 0);
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -25,12 +25,13 @@
  */
 
 $form = (new CForm('post'))
+	->addItem((new CVar(CCsrfTokenHelper::CSRF_TOKEN_NAME, CCsrfTokenHelper::get('sla')))->removeId())
 	->setId('sla-form')
 	->setName('sla_form')
 	->addItem(getMessages());
 
 // Enable form submitting on Enter.
-$form->addItem((new CInput('submit'))->addStyle('display: none;'));
+$form->addItem((new CSubmitButton(null))->addClass(ZBX_STYLE_FORM_SUBMIT_HIDDEN));
 
 // SLA tab.
 
@@ -43,7 +44,7 @@ for ($weekday = 0; $weekday < 7; $weekday++) {
 			->setChecked($data['form']['schedule_periods'][$weekday] !== ''),
 		(new CTextBox('schedule_periods['.$weekday.']', $data['form']['schedule_periods'][$weekday]))
 			->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
-			->setAttribute('placeholder', '8:00-17:00, &hellip;')
+			->setAttribute('placeholder', '8:00-17:00, ...')
 	]));
 }
 
@@ -136,7 +137,7 @@ $sla_tab = (new CFormGrid())
 								->addClass('element-table-add')
 						))
 					),
-				(new CScriptTemplate('service-tag-row-tmpl'))
+				(new CTemplateTag('service-tag-row-tmpl'))
 					->addItem(
 						(new CRow([
 							(new CTextBox('service_tags[#{rowNum}][tag]', '#{tag}', false,
