@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -25,14 +25,14 @@
 
 $this->addJsFile('class.calendar.js');
 
-(new CWidget())->show();
+(new CHtmlPage())->show();
 
 (new CScriptTag(
 	'PopUp("'.$data['popup']['action'].'", '.json_encode($data['popup']['options']).');'.
 
 	'$.subscribe("acknowledge.create", function(event, response, overlay) {'.
 		'clearMessages();'.
-		'addMessage(makeMessageBox("good", [], response.message, true, false));'.
+		'addMessage(makeMessageBox("good", [], response.success.title, true, false));'.
 	'});'
 ))
 	->setOnDocumentReady()
